summaryrefslogtreecommitdiffstats
path: root/parts/appwizard/common/scons/admin/kde.py
diff options
context:
space:
mode:
Diffstat (limited to 'parts/appwizard/common/scons/admin/kde.py')
-rw-r--r--parts/appwizard/common/scons/admin/kde.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/parts/appwizard/common/scons/admin/kde.py b/parts/appwizard/common/scons/admin/kde.py
index c67e0f41..2ed199f3 100644
--- a/parts/appwizard/common/scons/admin/kde.py
+++ b/parts/appwizard/common/scons/admin/kde.py
@@ -264,8 +264,8 @@ ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
objBuilder = getattr(env, self.objBuilderName)
# some regular expressions:
- # Q_OBJECT detection
- q_object_search = re.compile(r'[^A-Za-z0-9]Q_OBJECT[^A-Za-z0-9]')
+ # TQ_OBJECT detection
+ q_object_search = re.compile(r'[^A-Za-z0-9]TQ_OBJECT[^A-Za-z0-9]')
# The following is kind of hacky to get builders working properly (FIXME) ??
objBuilderEnv = objBuilder.env
@@ -323,7 +323,7 @@ ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
if not h and qtdebug:
print("scons: qt: no header for '%s'." % (str(cpp)))
if h and q_object_search.search(h_contents):
# h file with the Q_OBJECT macro found -> add .moc or _moc.cpp file
moc_cpp = None
if 'NOMOCSCAN' in env:
@@ -338,10 +338,10 @@ ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
moc_o = objBuilder(moc_cpp)
out_sources.append(moc_o)
if qtdebug:
- print("scons: qt: found Q_OBJECT macro in '%s', moc'ing to '%s'" % (str(h), str(moc_cpp[0])))
+ print("scons: qt: found TQ_OBJECT macro in '%s', moc'ing to '%s'" % (str(h), str(moc_cpp[0])))
if cpp and q_object_search.search(cpp_contents):
- print("error, bksys cannot handle cpp files with Q_OBJECT classes")
+ print("error, bksys cannot handle cpp files with TQ_OBJECT classes")
print("if you are sure this is a feature worth the effort, ")
print("report this to the authors tnagyemail-mail yahoo.fr")
@@ -323,7 +323,7 @@ ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
print("scons: qt: no header for '%s'." % (str(cpp)))
if h and q_object_search.search(h_contents):
- # h file with the Q_OBJECT macro found -> add .moc or _moc.cpp file
+ # h file with the TQ_OBJECT macro found -> add .moc or _moc.cpp file
moc_cpp = None
if 'NOMOCSCAN' in env: